[![Python 3.7+](https://img.shields.io/badge/python-v3.7+-blue.svg)](https://www.python.org/) [![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](LICENSE)
# Octowire library

A Python module which can be used to interface the Octowire from a script.

This library implements the Octowire binary protocol. 

The full documentation can be found here: [Octowire library documentation](https://github.com/immunIT/octowire-lib/wiki)

## Installing

```
# From this repository
$ python setup.py install

# From PyPi
$ pip install octowire-lib
```
